# hyppo

[![Build Status](https://travis-ci.org/neurodata/hyppo.svg?branch=master)](https://travis-ci.org/neurodata/hyppo)
[![codecov](https://codecov.io/gh/neurodata/mgc/branch/master/graph/badge.svg)](https://codecov.io/gh/neurodata/hyppo)
[![PyPI version](https://img.shields.io/pypi/v/hyppo.svg)](https://pypi.org/project/hyppo/)
[![License](https://img.shields.io/github/license/neurodata/hyppo)](https://hyppo.neurodata.io/license.html)
[![arXiv shield](https://img.shields.io/badge/arXiv-1907.02088-red.svg?style=flat)](https://arxiv.org/abs/1907.02088)

`hyppo` (**HYP**othesis Testing in **P**yth**O**n, pronounced "Hippo") is an open-source software package for hypothesis testing.

- **Installation Guide:** [https://hyppo.neurodata.io/install.html](https://hyppo.neurodata.io/install.html)
- **Documentation:** [https://hyppo.neurodata.io/](https://hyppo.neurodata.io/)
- **Tutorials:** [https://hyppo.neurodata.io/tutorials.html](https://hyppo.neurodata.io/tutorials.html)
- **Source Code:** [https://github.com/neurodata/hyppo/tree/master/hyppo](https://github.com/neurodata/hyppo/tree/master/hyppo)
- **Issues:** [https://github.com/neurodata/hyppo/issues](https://github.com/neurodata/hyppo/issues)
- **Contribution Guide:** [https://hyppo.neurodata.io/contributing.html](https://hyppo.neurodata.io/contributing.html)

`hyppo` intends to be a comprehensive hypothesis testing package and runs on all major versions of operating systems. It also includes novel tests not found in other packages that operate on multivariate data. It is quick to install and free of charge. If you need to use multivariate hypothesis testing, be sure to give `hyppo` a try!
